<?php
/****************************************************************
 * This file is part of InFrame
 * Copyright (c) 2008 Richard Tong. All Rights Reserved.
 * 
 * Licensed under the terms of the GNU General Public License.
 * See http://opensource.org/licenses/gpl-license.php
 * 
 ****************************************************************/

class Exif
{
   public static function createDB($dbname)
   {
     $db = new FFDB();
     $schema = array(
     	array("id", FFDB_INT_AUTOINC, "key"),
     	array("photoid", FFDB_INT),
     	array("make", FFDB_STRING),
     	array("model", FFDB_STRING),
     	array("fstop", FFDB_STRING),
     	array("shutter", FFDB_STRING),
     	array("flash", FFDB_INT),
     	array("iso", FFDB_INT),
     	array("focal", FFDB_STRING),
     	array("datetaken", FFDB_STRING));
     $db->create($dbname, $schema);
     $db->close();
     unset($db);
     unset($schema);
     unset($dbname);
   }
   
   public static function saveExif($dbname, $id, $f)
   {
	$db = new FFDB();
   	$db->open($dbname);

    $record["photoid"] = (int)$id;

	if (exif_imagetype($f) != IMAGETYPE_JPEG) // not jpeg
	{
   		$record["make"] = "NA";
	   	$record["model"] = "NA";
	   	$record["fstop"] = "NA";
	   	$record["shutter"] = "NA";
	   	$record["iso"] = 0;
	   	$record["flash"] = 0;
	   	$record["focal"] = "NA";
		$record["datetaken"] = "NA";
	}
	else
	{   	
	   	$exif = exif_read_data($f, 0, true);
   	 
		if (strlen($exif["IFD0"]["Make"]) > 0)
   			$record["make"] = $exif["IFD0"]["Make"];
   		else
	   		$record["make"] = "NA";

		if (strlen($exif["IFD0"]["Model"]) > 0)
		   	$record["model"] = $exif["IFD0"]["Model"];
		else
		   	$record["model"] = "NA";

		if (strlen($exif["COMPUTED"]["ApertureFNumber"]) > 0)
	   		$record["fstop"] = $exif["COMPUTED"]["ApertureFNumber"];
		else
		   	$record["fstop"] = "NA";

		if (strlen($exif["EXIF"]["ExposureTime"]) > 0)
	   		$record["shutter"] = $exif["EXIF"]["ExposureTime"]."sec";
		else
		   	$record["shutter"] = "NA";

		if (strlen($exif["EXIF"]["ISOSpeedRatings"]) > 0)
	   		$record["iso"] = (int)$exif["EXIF"]["ISOSpeedRatings"];
		else
		   	$record["iso"] = 0;

		if (strlen($exif["EXIF"]["Flash"]) > 0)
	   		$record["flash"] = (int)$exif["EXIF"]["Flash"];
		else
		   	$record["flash"] = 0;

		if (strlen($exif["EXIF"]["FocalLength"]) > 0)
	   		$record["focal"] = $exif["EXIF"]["FocalLength"];
		else
		   	$record["focal"] = "NA";

		if (strlen($exif["EXIF"]["DateTimeOriginal"]) > 0)
	   		$record["datetaken"] = $exif["EXIF"]["DateTimeOriginal"];
		else
			$record["datetaken"] = "NA";
		}
		
     $result = $db->add($record);
     $db->close();
     unset($db);
     unset($record);
     if ($result)
     	return true;
     else
     	return false;
	}
	public static function showAll($idx)
	{
		$db = new FFDB();
		$db->open(ABSP."/Data/Exif");
		$record = $db->getbyfield("photoid", "/".$idx."/i");
		$db->close();
		unset($db);
   		$str = "<b>Make</b>: ".$record[0]["make"];
   		$str = $str."<br /><b>Model</b>: ".$record[0]["model"];
   		$str = $str."<br /><b>Aperture</b>: ".$record[0]["fstop"];
   		$str = $str."<br /><b>Shutter speed</b>: ".$record[0]["shutter"];
   		$str = $str."<br /><b>ISO</b>: ".$record[0]["iso"];
   		$str = $str."<br /><b>Flash</b>: ".$record[0]["flash"];
   		$str = $str."<br /><b>Focal length</b>: ".$record[0]["focal"];
   		$str = $str."<br /><b>Date taken</b>: ".$record[0]["datetaken"];

   		return $str;
	}   

	public static function deleteAllByID($i)
	{
		$db = new FFDB();
		$db->open(ABSP."/Data/Exif");
		$result = $db->removebyfield("photoid", "/".$i."/i");
		$db->cleanup();
		$db->close();
		unset($db);
   		return $result;
	}   

	public static function make($idx)
	{
		$db = new FFDB();
		$db->open(ABSP."/Data/Exif");
		$record = $db->getbyindex($idx);
		$db->close();
		unset($db);
		return $record["camera"];
    }
	public static function model($idx)
	{
		$db = new FFDB();
		$db->open(ABSP."/Data/Exif");
		$record = $db->getbyindex($idx);
		$db->close();
		unset($db);
		return $record["model"];
    }
	public static function fstop($idx)
	{
		$db = new FFDB();
		$db->open(ABSP."/Data/Exif");
		$record = $db->getbyindex($idx);
		$db->close();
		unset($db);
		return $record["fstop"];
    }
	public static function shutter($idx)
	{
		$db = new FFDB();
		$db->open(ABSP."/Data/Exif");
		$record = $db->getbyindex($idx);
		$db->close();
		unset($db);
		return $record["shutter"];
    }
	public static function iso($idx)
	{
		$db = new FFDB();
		$db->open(ABSP."/Data/Exif");
		$record = $db->getbyindex($idx);
		$db->close();
		unset($db);
		return $record["iso"];
    }
	public static function focal($idx)
	{
		$db = new FFDB();
		$db->open(ABSP."/Data/Exif");
		$record = $db->getbyindex($idx);
		$db->close();
		unset($db);
		return $record["focal"];
    }
	public static function dateTaken($idx)
	{
		$db = new FFDB();
		$db->open(ABSP."/Data/Exif");
		$record = $db->getbyindex($idx);
		$db->close();
		unset($db);
		return $record["datetaken"];
    }
}
?>
