<?php
/****************************************************************
 * This file is part of InFrame
 * Copyright (c) 2008 Richard Tong. All Rights Reserved.
 * 
 * Licensed under the terms of the GNU General Public License.
 * See http://opensource.org/licenses/gpl-license.php
 * 
 ****************************************************************/

class Photo
{
   public static function createDB($dbname)
   {
     $db = new FFDB();
     $schema = array(
     	array("id", FFDB_INT_AUTOINC, "key"),
     	array("filename", FFDB_STRING),
     	array("size", FFDB_INT),
     	array("title", FFDB_STRING),
     	array("caption", FFDB_STRING),
     	array("description", FFDB_STRING),
     	array("dateadded", FFDB_STRING),
     	array("gmtdateadded", FFDB_STRING),
     	array("views", FFDB_INT),
     	array("book", FFDB_STRING));
     $db->create($dbname, $schema);
     $db->close();
     unset($db);
     unset($schema);
     unset($dbname);
   }
   
   public static function savePost($dbname, $fn, $ti, $ca, $ds)
   {
   	 $db = new FFDB();
   	 $db->open($dbname);
     $record["filename"] = $fn;
     $record["size"] = filesize(ABSP."/Data/Image/".$fn);
     if (strlen($ti) < 1)
     	$record["title"] = "Untitled";
     else
     	$record["title"] = $ti;
     if (strlen($ca) < 1)
     	$record["caption"] = "none";
     else
     	$record["caption"] = $ca;
     if (strlen($ds) < 1)
	     $record["description"] = "none";
	 else
	     $record["description"] = $ds;
     $record["dateadded"] = date('l, M jS Y, \a\t h:ia');
     $record["gmtdateadded"] = date('r');
     $record["views"] = 0;
     $record["book"] = "Unassigned";
     $result = $db->add($record);
     $db->close();
     unset($db);
     unset($record);
     if ($result)
     	return true;
     else
     	return false;
	}
   
   public static function saveEditedPost($dbname, $id, $ti, $ca, $ds)
   {
   	 $db = new FFDB();
   	 $db->open($dbname);
   	 $record = $db->getbykey($id);
   	 $record["id"] = $id;
     if (strlen($ti) < 1)
     	$record["title"] = "Untitled";
     else
     	$record["title"] = $ti;
     if (strlen($ca) < 1)
     	$record["caption"] = "none";
     else
     	$record["caption"] = $ca;
     if (strlen($ds) < 1)
	     $record["description"] = "none";
	 else
	     $record["description"] = $ds;
     $result = $db->edit($record);
     $db->close();
     unset($db);
     unset($record);
     if ($result)
     	return true;
     else
     	return false;
	}

	public static function deletePost($dbname, $i)
	{
		Comments::deleteAllByID($i);
		Ratings::deleteRatingsByID($i);
		Exif::deleteAllByID($i);
		$f = Photo::fileName($i);
		$ext = substr($f, strrpos($f, '.') + 1);
		if (file_exists(ABSP."/Data/Image/".$f))
			unlink(ABSP."/Data/Image/".$f);
		if (file_exists(ABSP."/Data/Image/".basename($f, ".".$ext)."-disp.png"))
			unlink(ABSP."/Data/Image/".basename($f, ".".$ext)."-disp.png");
		if (file_exists(ABSP."/Data/Image/".basename($f, ".".$ext)."-thumb.png"))
			unlink(ABSP."/Data/Image/".basename($f, ".".$ext)."-thumb.png");
		$db = new FFDB();
		$db->open($dbname);
		$result = $db->removebykey($i);
		$db->cleanup();
		$db->close();
		unset($db);
		return $result;
	}
	
	public static function displayPhoto($i)
	{
		$f = Photo::fileName($i);
		$ext = substr($f, strrpos($f, '.') + 1);
		if (Config::allowViewExif())
		{
			if (Config::showOriginal() && file_exists(ABSP."/Data/Image/".$f))
				echo "<a title=\"View original version\" href=\"".URLTOP."Data/Image/".$f."\" target=\"_\"><img class=\"display\" src=\"".URLTOP."Data/Image/".basename($f, ".".$ext)."-disp.png\" onMouseOut=\"popout()\" onMouseOver=\"popup('".Exif::showAll($i)."')\" /></a>\n";
			else
				echo "<img class=\"display\" src=\"".URLTOP."Data/Image/".basename($f, ".".$ext)."-disp.png\" onMouseOut=\"popout()\" onMouseOver=\"popup('".Exif::showAll($i)."')\" />\n";
		}
		else
		{
			if (Config::showOriginal() && file_exists(ABSP."/Data/Image/".$f))
				echo "<a title=\"View original version\" href=\"".URLTOP."Data/Image/".$f."\" target=\"_\"><img class=\"display\" src=\"".URLTOP."Data/Image/".basename($f, ".".$ext)."-disp.png\" /></a>\n";
			else
				echo "<img class=\"display\" src=\"".URLTOP."Data/Image/".basename($f, ".".$ext)."-disp.png\" />\n";
		}
	}
	
	public static function totalPosts()
	{
		$db = new FFDB();
		$db->open(ABSP."/Data/InFrame");
		$size = $db->size();
		$db->close();
		unset($db);
		return $size;
   }

	public static function showPosts()
	{
		$db = new FFDB();
		$db->open(ABSP."/Data/InFrame");
		$records = $db->getall();
		$db->close();
		unset($db);
		echo "<div>&nbsp;</div><div>&nbsp;</div>";
		foreach ($records as $record)
		{
			$f = $record["filename"];
			$ext = substr($f, strrpos($f, '.') + 1);
			echo "<table><tr>
			<td valign=\"top\" width=\"20%\"><a href=\"".URLTOP."index.php?id=".$record["id"]."\" title=\"View photo\"><img class=\"thumb\" src=\"".URLTOP."Data/Image/".basename($f, ".".$ext)."-thumb.png\" alt=\"".stripcslashes($record["title"])."\" /></a></td>
			<td valign=\"top\" width=\"60%\">
			<table>
			<tr><td><span style=\"font-size: large\">".stripcslashes($record["title"])."</span></td></tr>";

			if ($record["caption"] == "none")
				echo "<tr><td><span style=\"font-size: small; font-style: italic; color:lightgray\">This post has no caption.</td></tr>";
			else
				echo "<tr><td><span style=\"font-size: small; font-style: italic; color:lightgray\">".stripcslashes($record["caption"])."</td></tr>";

			if ($record["caption"] == "none")
				echo "<tr><td><span style=\"font-size: small; color:lightgray\">This post has no description.</td></tr>";
			else
				echo "<tr><td><span style=\"font-size: small; color:lightgray\">".stripcslashes($record["description"])."</td></tr>";
			
			echo "</table></td>";
			
			if (User::isLoggedIn())
			{
				echo "<td valign=\"top\" width=\"20%\">
					<table>
					<tr><td><a href=\"".URLTOP."index.php?op=ep&id=".$record["id"]."\">edit</a>&nbsp;&nbsp;
					<a href=\"".URLTOP."index.php?op=dpo&id=".$record["id"]."\" onClick=\"return verify()\">delete</a>
					</td>";
			}
			else
				echo "<td>&nbsp;</td>";
			
			echo "</tr>
			</table></td>
			</tr></table>";
		}
    }

	public static function fileName($idx)
	{
		$db = new FFDB();
		$db->open(ABSP."/Data/InFrame");
		$record = $db->getbykey($idx);
		$db->close();
		unset($db);
		return $record["filename"];
   }
	public static function size($idx)
	{
		$db = new FFDB();
		$db->open(ABSP."/Data/InFrame");
		$record = $db->getbykey($idx);
		$db->close();
		unset($db);
		return $record["size"];
   }

	public static function title($idx)
	{
		$db = new FFDB();
		$db->open(ABSP."/Data/InFrame");
		$record = $db->getbykey($idx);
		$db->close();
		unset($db);
		return $record["title"];
   }
   
	public static function caption($idx)
	{
		$db = new FFDB();
		$db->open(ABSP."/Data/InFrame");
		$record = $db->getbykey($idx);
		$db->close();
		unset($db);
		return $record["caption"];
   }

	public static function desc($idx)
	{
		$db = new FFDB();
		$db->open(ABSP."/Data/InFrame");
		$record = $db->getbykey($idx);
		$db->close();
		unset($db);
		return $record["description"];
	}
	
	public static function dateAdded($idx)
	{
		$db = new FFDB();
		$db->open(ABSP."/Data/InFrame");
		$record = $db->getbykey($idx);
		$db->close();
		unset($db);
		return $record["dateadded"];
	}
	
	public static function views($idx)
	{
		$db = new FFDB();
		$db->open(ABSP."/Data/InFrame");
		$record = $db->getbykey($idx);
		$db->close();
		unset($db);
		return $record["views"];
	}
	
	public static function book($idx)
	{
		$db = new FFDB();
		$db->open(ABSP."/Data/InFrame");
		$record = $db->getbykey($idx);
		$db->close();
		unset($db);
		return $record["book"];
	}
	
	public static function process($f)
	{
		list($w, $h) = getimagesize($f);
		
		$watermark = ABSP."/Image/watermark.png";
		if (file_exists($watermark))
		{
			$addWatermark = true;
			list($wmw, $wmh) = getimagesize($watermark);
			$wmImage = imagecreatefrompng($watermark);
		}
		
		if ($w >= $h)  // horizontal photo (or square photo)
		{
			$longSide = Config::dimX();
			if ($longSide > $w)
				$displayRatio = 1;
			else
				$displayRatio = $longSide / $w;
			$thumbRatio = 150 / $h;  // We'll resize short side not long side like the display
		}
		else  // vertical photo
		{
			$longSide = Config::dimY();
			if ($longSide > $h)
				$displayRatio = 1;
			else
				$displayRatio = $longSide / $h;
			$thumbRatio = 150 / $w;
		}
		
		$newDispWidth = $w * $displayRatio;
		$newDispHeight = $h * $displayRatio;
		$newThumbWidth = $w * $thumbRatio;
		$newThumbHeight = $h * $thumbRatio;
		$displayImage = imagecreatetruecolor($newDispWidth, $newDispHeight);
		$tmpImage = imagecreatetruecolor($newThumbWidth, $newThumbHeight);  // temp resized thumbnail
		$thumbNail = imagecreatetruecolor(150,150);

		// We can accept the following file types
		// They will be converted to true color png for displaying
		$ext = substr($f, strrpos($f, '.') + 1);
		switch(strtolower($ext))
		{
			case "jpg":
				$fullImage = imagecreatefromjpeg($f);
				break;
			case "png":
				$fullImage = imagecreatefrompng($f);
				break;
			case "gif":
				$fullImage = imagecreatefromgif($f);
				break;
			case "xbm":
				$fullImage = imagecreatefromxbm($f);
				break;
			case "xpm":
				$fullImage = imagecreatefromxpm($f);
				break;
			case "bmp":
				$fullImage = imagecreatefromwbmp($f);
				break;
			default:
				Page::renderAdmin("np", true);
		}
		imagecopyresampled($displayImage, $fullImage, 0, 0, 0, 0, $newDispWidth, $newDispHeight, $w, $h);
		if ($addWatermark)
		{
			imagecopymerge($displayImage, $wmImage, $newDispWidth-$wmw-20, $newDispHeight-$wmh-20, 0, 0, $wmw, $wmh, 60);
			imagedestroy($wmImage);
		}
		imagecopyresampled($tmpImage, $fullImage, 0, 0, 0, 0, $newThumbWidth, $newThumbHeight, $w, $h);
		imagecopyresampled($thumbNail, $tmpImage, 0, 0, 0, 0, 150, 150, 150, 150);
		imagepng($displayImage, dirname($f)."/".basename($f, ".".$ext)."-disp.png", 9, PNG_NO_FILTER);
		imagepng($thumbNail, dirname($f)."/".basename($f, ".".$ext)."-thumb.png", 9, PNG_NO_FILTER);
		imagedestroy($tmpImage);
		imagedestroy($thumbNail);
		imagedestroy($displayImage);
		imagedestroy($fullImage);
	}

	public static function trackViews($i)
	{
		if ($_SESSION["beenhere$i"] != "yes")
		{
			Photo::saveView($i);
			$_SESSION["beenhere$i"] = "yes";
		}
	}
	
	public static function saveView($i)
	{
		$db = new FFDB();
		$db->open(ABSP."/Data/InFrame");
		$record = $db->getbykey($i);
		$record["views"] += 1;
		$db->edit($record);
		$db->close();
		unset($db);
	}
	public static function resetViews($i)
	{
		$db = new FFDB();
		$db->open(ABSP."/Data/InFrame");
		$record = $db->getbykey($i);
		$record["views"] = 0;
		$db->edit($record);
		$db->close();
		unset($db);
	}
	public static function getID($sortby)
	{
		$db = new FFDB();
		$db->open(ABSP."/Data/InFrame");
		if ($sortby == "Newest first")
		{
			$records = $db->getall("!id");
			$id = $records[0]["id"];
		}
		else if ($sortby == "Oldest first")
		{
			$records = $db->getall();
			$id = $records[0]["id"];
		}
		else // Shuffle
		{
			$records = $db->getall();
			$randnum = rand(0, ($db->size() - 1));
			$id = $records[$randnum]["id"];
		}
		$db->close();
		unset($db);
		return $id;
	}
}
?>
